@@ -1,7 +1,8 @@
 package Language::Expr;
 # ABSTRACT: Simple minilanguage for use in expression
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
+our $DATE = '2014-04-28'; # DATE
 
 
 use 5.010001;
@@ -144,13 +145,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Language::Expr - Simple minilanguage for use in expression
 
 =head1 VERSION
 
-version 0.21
+This document describes version 0.22 of module Language::Expr (in distribution Language-Expr), released on 2014-04-28.
 
 =head1 SYNOPSIS
 
@@ -225,7 +228,7 @@ This distribution consists of the language parser
 (Language::Expr::Interpreter::*), and some compilers
 (Language::Expr::Compiler::*).
 
-=head1 ATTRIBUTES
+=head1 ATTRIBUTES (MANUAL)
 
 =head2 interpreted => BOOL
 
@@ -359,7 +362,7 @@ modifying the Language::Expr::Parser module.
 
 This is a TODO item.
 
-=head1 BUGS
+=head1 KNOWN BUGS
 
 Due to possible bugs in Perl's RE engine or Regexp::Grammars or my
 grammar, some syntax errors will cause further parsing to
@@ -375,13 +378,29 @@ L<Data::Template::Expr> (not yet released).
 Other related modules: L<Math::Expression>,
 L<Math::Expression::Evaluator>, L<Language::Farnsworth>
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Language-Expr>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Language-Expr>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Language-Expr>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
