@@ -1,7 +1,7 @@
 package Language::Expr::Compiler::Base;
 # ABSTRACT: Base class for Expr compilers
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 use 5.010;
 use strict;
@@ -57,15 +57,17 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Language::Expr::Compiler::Base - Base class for Expr compilers
 
 =head1 VERSION
 
-version 0.21
+This document describes version 0.22 of module Language::Expr::Compiler::Base (in distribution Language-Expr), released on 2014-04-28.
 
-=head1 ATTRIBUTES
+=head1 ATTRIBUTES (MANUAL)
 
 =head2 markers => ARRAYREF
 
@@ -123,13 +125,29 @@ Return an array of all marker IDs.
 
 Return a regex that matches marker IDs.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Language-Expr>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Language-Expr>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Language-Expr>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
