@@ -1,7 +1,7 @@
 package Language::Expr::Compiler::Perl;
 # ABSTRACT: Compile Language::Expr expression to Perl
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 use 5.010;
 use strict;
@@ -407,13 +407,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Language::Expr::Compiler::Perl - Compile Language::Expr expression to Perl
 
 =head1 VERSION
 
-version 0.21
+This document describes version 0.22 of module Language::Expr::Compiler::Perl (in distribution Language-Expr), released on 2014-04-28.
 
 =head1 SYNOPSIS
 
@@ -469,13 +471,29 @@ hook_func() (see documentation in L<Language::Expr::Compiler::Base>).
 Convert Language::Expr expression into Perl code. Dies if there is
 syntax error in expression.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Language-Expr>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Language-Expr>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Language-Expr>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
