@@ -1,7 +1,7 @@
 package Language::Expr::Parser;
 # ABSTRACT: Parse Language::Expr expression
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 use 5.010;
 # now can't compile with this on?
@@ -297,13 +297,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Language::Expr::Parser - Parse Language::Expr expression
 
 =head1 VERSION
 
-version 0.21
+This document describes version 0.22 of module Language::Expr::Parser (in distribution Language-Expr), released on 2014-04-28.
 
 =head1 METHODS
 
@@ -311,7 +313,7 @@ version 0.21
 
 Parse expression in $str. Will call various rule_*() methods in $obj.
 
-=head1 BUGS
+=head1 KNOWN BUGS
 
 =over 4
 
@@ -319,13 +321,29 @@ Parse expression in $str. Will call various rule_*() methods in $obj.
 
 =back
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Language-Expr>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Language-Expr>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Language-Expr>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
